#
# spec file for package gpxsee
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           gpxsee
Version:        4.6
Release:        1.1
Summary:        GPS log files visualizing and analyzing tool
License:        GPL-3.0
Group:          Productivity/Graphics/Visualization
Url:            http://tumic.wz.cz/gpxsee
Source0:        GPXSee-%{version}.tar.gz
Source1:        gpxsee.desktop
Source2:        gpxsee.xml

BuildRequires:  gcc-c++
BuildRequires:  make
%if 0%{?fedora_version}
%if 0%{?fedora_version} >= 24
BuildRequires:  qt5-qtbase
BuildRequires:  qt5-qtbase-gui
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-linguist
%else
BuildRequires:  libqt4-devel
%endif
%endif
%if 0%{?suse_version}
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Gui-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5PrintSupport-devel
BuildRequires:  libqt5-linguist
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  libqt4-devel
%endif


%description
GPXSee is a Qt-based tool for visualizing and analyzing GPX, TCX, FIT, KML,
IGC, NMEA and Garmin CSV files.

%prep
%setup -q -n GPXSee-%{version}

%build
%if 0%{?fedora_version} >= 24 || 0%{?suse_version}
lrelease-qt5 gpxsee.pro
qmake-qt5 gpxsee.pro
%else
lrelease-qt4 gpxsee.pro
qmake-qt4 gpxsee.pro
%endif
make %{?_smp_mflags}
make clean


%install
install -d 755 %{buildroot}/%{_bindir}
install -d 755 %{buildroot}/%{_datadir}/applications
install -d 755 %{buildroot}/%{_datadir}/pixmaps
install -d 755 %{buildroot}/%{_datadir}/mime/packages
install -d 755 %{buildroot}/%{_datadir}/%{name}
install -m 755 GPXSee %{buildroot}/%{_bindir}/%{name}
install -m 644 pkg/maps.txt %{buildroot}/%{_datadir}/%{name}
install -m 644 pkg/ellipsoids.csv %{buildroot}/%{_datadir}/%{name}
install -m 644 pkg/datums.csv %{buildroot}/%{_datadir}/%{name}
install -m 644 icons/gpxsee.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png
install -m 644 %{SOURCE1} %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -m 644 %{SOURCE2} %{buildroot}/%{_datadir}/mime/packages/%{name}.xml

%post
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%postun
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%files
%defattr(-,root,root)
%dir %{_datadir}/gpxsee
%{_bindir}/*
%{_datadir}/%{name}/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*

%changelog
* Tue May  2 2017 tumic@cbox.cz
- Update to version 4.6
  * Fixed broken PDF export/printing (broken map scale/waypoints
    size).
  * Improved path projection performance when an atlas is used.
* Sun Apr 23 2017 tumic@cbox.cz
- Update to version 4.5
  * Added support for "runtime" loading of offline maps.
  * Fixed atlas zoom fitting.
  * Fixed various minor offline map loading issues.
* Mon Apr 17 2017 tumic@cbox.cz
- Update to version 4.4
  * Added support for ozf2 image files.
  * Added full support for non-WGS84 datum based offline maps.
  * Added German localization.
* Wed Apr 12 2017 tumic@cbox.cz
- Update to version 4.3
  * Fixed missing cached content cleanup causing huge draw areas
    (causing memory exhaustion) issue.
  * Fixed map file defined datum not set for UTM maps issue.
* Thu Apr  6 2017 tumic@cbox.cz
- Update to version 4.2
  * Added digital zoom.
  * Fixed atlas map fitting algorithm.
  * Completed Swedish translation.
* Sun Apr  2 2017 tumic@cbox.cz
- Update to version 4.1
  * Added support for Lambert conformal conic projection.
* Sat Apr  1 2017 tumic@cbox.cz
- Update to version 4.0
  * Added support for offline maps.
  * Fixed zoom issues on touchpads.
* Mon Feb 13 2017 tumic@cbox.cz
- Update to version 3.9
  * Fixed broken POI radius computation.
  * Added moving time info.
  * Improved pause detection/handling.
* Tue Jan 24 2017 tumic@cbox.cz
- Update to version 3.8
  * Fixed graph info not redrawing issue.
  * Added Swedish localization.
* Mon Jan 23 2017 tumic@cbox.cz
- Update to version 3.7
  * Fixed tile downloading issues (multiple downloads, redirect
    loop).
  * Enabled free map scroll.
* Tue Dec 20 2016 tumic@cbox.cz
- Update to version 3.5
  * Fixed broken NMEA latitude parsing.
  * Added print/export options.
* Sat Dec 10 2016 tumic@cbox.cz
- Update to version 3.4
  * Fixed QT5 < 5.4 builds (Debian 8).
* Fri Dec  9 2016 tumic@cbox.cz
- Update to version 3.3
  * Added options dialog with basic appearance settings.
  * Added OpenGL support.
* Tue Nov 22 2016 tumic@cbox.cz
- Update to version 3.2
  * Added support for NMEA files.
  * Fixed path marker inaccuracy bug.
* Sat Nov 12 2016 tumic@cbox.cz
- Update to version 3.1
  * Added support for IGC files.
  * Fixed zoom level computation bugs.
* Mon Nov  7 2016 tumic@cbox.cz
- Update to version 3.0
  * Added support for TCX, KML and FIT files.
  * Added cadence and power graphs.
  * Improved outlier detection (now also applies to track points).
  * GUI polishing.
  * Improved print output.
* Sun Oct 16 2016 tumic@cbox.cz
- Update to version 2.20
  * Added support for drag&drop.
  * Fixed graph line distortion in PDF output.
  * Fixed POI loading performance issue.
  * GUI polishing.
* Wed Sep 28 2016 tumic@cbox.cz
- Update to version 2.19
  * Added time-based graphs.
  * Added track/graph highlighting (on track hover).
  * Added support for proxy connections (using the system-defined
    proxy).
  * Fixed PDF output in QT4 builds.
* Wed Aug 31 2016 tumic@cbox.cz
- Update to version 2.18
  * Added support for GPX routes.
  * Added various data display options.
  * Improved performance.
* Wed Aug  3 2016 tumic@cbox.cz
- Update to version 2.17
  * Added waypoint/track info tooltips.
  * Improved POI handling.
* Thu Jun 16 2016 tumic@cbox.cz
- Update to version 2.16
  * Fixed infinite download loop on HTTP redirects (and broken
    images).
  * Fixed handling of GPX files with inconsistent track point
    entries.
  * Added support for temperature graphs.
* Sat May 28 2016 tumic@cbox.cz
- Update to version 2.14
  * Added print support.
  * Many fixes & improvements in PDF export (e.g. map support).
* Tue May  3 2016 tumic@cbox.cz
- Update to version 2.13
  * Fixed broken opening of non-ASCII named files as program
    arguments.
  * File info in window title.
  * Persistent program settings.
* Thu Apr 14 2016 tumic@cbox.cz
- Update to version 2.12
  * Added fullscreen mode.
  * Polished GUI.
* Sat Apr  2 2016 tumic@cbox.cz
- Update to version 2.11
  * Added "clear tile cache" option.
  * Lots of minor bug fixes and enhancements.
* Fri Mar 25 2016 tumic@cbox.cz
- Update to version 2.10
  * Added heart rate graphs.
  * Polished GUI.
  * Redesigned map/POI data sources handling.
  * Lots of minor bug fixes and enhancements.
* Sun Mar 20 2016 tumic@cbox.cz
- Update to version 2.9
  * Added support for displaying waypoints.
  * Minor bug fixes and enhancements.
* Sun Mar  6 2016 tumic@cbox.cz
- Update to version 2.8
  * Improved POI files control.
  * Minor bug fixes and enhancements.
* Sat Feb 13 2016 tumic@cbox.cz
- Update to version 2.7
  * Added default map sources (OSM, Thunderforest).
  * Added support for POIs in GPX format.
  * Added support for GPX files with multiple tracks.
* Wed Feb  3 2016 tumic@cbox.cz
- Update to version 2.6
  * Added map scale info.
  * Improved PDF export.
* Sun Dec 20 2015 tumic@cbox.cz
- Update to version 2.5
  * Added support for imperial units.
  * Fixed track view resizing issues.
